@@ -31,7 +31,7 @@ exception Json_error of string
 val json_error : string -> 'a
 
 type lexer_state = {
-  buf : Bi_outbuf.t;
+  buf : Buffer.t;
     (** Buffer used to accumulate substrings *)
 
   mutable lnum : int;
@@ -48,7 +48,7 @@ type lexer_state = {
 module Lexer_state :
 sig
   type t = lexer_state = {
-    buf : Bi_outbuf.t;
+    buf : Buffer.t;
     mutable lnum : int;
     mutable bol : int;
     mutable fname : string option;
@@ -56,7 +56,7 @@ sig
 end
 
 val init_lexer :
-  ?buf: Bi_outbuf.t ->
+  ?buf: Buffer.t ->
   ?fname: string ->
   ?lnum: int ->
   unit -> lexer_state
@@ -133,11 +133,6 @@ All possible cases defined in Yojson:
 	    Syntax: [<"Foo">] or [<"Bar":123>].
 *)
 
-type json = t [@@deprecated "json types are being renamed and will be removed in the next Yojson major version. Use type t instead"]
-(**
- * Compatibility type alias for type `t`
- *)
-
 (*
   Note to adventurers: ocamldoc does not support inline comments
   on each polymorphic variant, and cppo doesn't allow to concatenate
@@ -148,13 +143,13 @@ type json = t [@@deprecated "json types are being renamed and will be removed in
 (** {2 JSON writers} *)
 
 val to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t -> string
   (** Write a compact JSON value to a string.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create]. The buffer is cleared of all contents
+      [Buffer.create]. The buffer is cleared of all contents
       before starting and right before returning.
       @param len initial length of the output buffer.
       @param std use only standard JSON syntax,
@@ -165,13 +160,13 @@ val to_string :
   *)
 
 val to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t -> unit
   (** Write a compact JSON value to a channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_channel_writer] on the same channel.
+      [Buffer.create] on the same channel.
       [buf] is flushed right
       before [to_channel] returns but the [out_channel] is
       not flushed automatically.
@@ -179,13 +174,13 @@ val to_channel :
       See [to_string] for the role of the other optional arguments. *)
 
 val to_output :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   < output : string -> int -> int -> int; .. > -> t -> unit
   (** Write a compact JSON value to an OO channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_output_writer] on the same channel.
+      [Buffer.add_channel] on the same channel.
       [buf] is flushed right
       before [to_output] returns but the channel itself is
       not flushed automatically.
@@ -199,14 +194,14 @@ val to_file :
   (** Write a compact JSON value to a file.
       See [to_string] for the role of the optional arguments. *)
 
-val to_outbuf :
+val to_buffer :
   ?std:bool ->
-  Bi_outbuf.t -> t -> unit
+  Buffer.t -> t -> unit
   (** Write a compact JSON value to an existing buffer.
       See [to_string] for the role of the optional argument. *)
 
 val stream_to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t Stream.t -> string
@@ -215,7 +210,7 @@ val stream_to_string :
       See [to_string] for the role of the optional arguments. *)
 
 val stream_to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t Stream.t -> unit
@@ -231,15 +226,15 @@ val stream_to_file :
       a file.
       See [to_string] for the role of the optional arguments. *)
 
-val stream_to_outbuf :
+val stream_to_buffer :
   ?std:bool ->
-  Bi_outbuf.t ->
+  Buffer.t ->
   t Stream.t -> unit
   (** Write a newline-separated sequence of compact one-line JSON values to
       an existing buffer.
       See [to_string] for the role of the optional arguments. *)
 
-val write_t : Bi_outbuf.t -> t -> unit
+val write_t : Buffer.t -> t -> unit
 (** Write the given JSON value to the given buffer.
     Provided as a writer function for atdgen.
 *)
@@ -254,28 +249,28 @@ val sort : t -> t
 (**/**)
 (* begin undocumented section *)
 
-val write_null : Bi_outbuf.t -> unit -> unit
-val write_bool : Bi_outbuf.t -> bool -> unit
+val write_null : Buffer.t -> unit -> unit
+val write_bool : Buffer.t -> bool -> unit
 # 113 "write.mli"
-val write_int : Bi_outbuf.t -> int -> unit
+val write_int : Buffer.t -> int -> unit
 # 116 "write.mli"
-val write_float : Bi_outbuf.t -> float -> unit
-val write_std_float : Bi_outbuf.t -> float -> unit
-val write_float_fast : Bi_outbuf.t -> float -> unit
-val write_std_float_fast : Bi_outbuf.t -> float -> unit
-val write_float_prec : int -> Bi_outbuf.t -> float -> unit
-val write_std_float_prec : int -> Bi_outbuf.t -> float -> unit
+val write_float : Buffer.t -> float -> unit
+val write_std_float : Buffer.t -> float -> unit
+val write_float_fast : Buffer.t -> float -> unit
+val write_std_float_fast : Buffer.t -> float -> unit
+val write_float_prec : int -> Buffer.t -> float -> unit
+val write_std_float_prec : int -> Buffer.t -> float -> unit
 # 124 "write.mli"
-val write_string : Bi_outbuf.t -> string -> unit
+val write_string : Buffer.t -> string -> unit
 
 
 # 137 "write.mli"
-val write_assoc : Bi_outbuf.t -> (string * t) list -> unit
-val write_list : Bi_outbuf.t -> t list -> unit
+val write_assoc : Buffer.t -> (string * t) list -> unit
+val write_list : Buffer.t -> t list -> unit
 
 # 148 "write.mli"
-val write_json : Bi_outbuf.t -> t -> unit
-val write_std_json : Bi_outbuf.t -> t -> unit
+val write_json : Buffer.t -> t -> unit
+val write_std_json : Buffer.t -> t -> unit
 
 (* end undocumented section *)
 (**/**)
@@ -296,13 +291,6 @@ val equal : t -> t -> bool
 # 1 "write2.mli"
 (** {2 JSON pretty-printing} *)
 
-val pretty_format : ?std:bool -> t -> Easy_format.t
-  (** Convert into a pretty-printable tree.
-      See [to_string] for the role of the optional [std] argument.
-
-      @see <http://martin.jambon.free.fr/easy-format.html> Easy-format
-  *)
-
 val pretty_print : ?std:bool -> Format.formatter -> t -> unit
   (** Pretty-print into a {!Format.formatter}.
       See [to_string] for the role of the optional [std] argument.
@@ -333,7 +321,7 @@ exception Finally of exn * exn
 (** Exception describing a failure in both finalizer and parsing. *)
 
 val from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -346,7 +334,7 @@ val from_string :
   *)
 
 val from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   in_channel -> t
@@ -354,7 +342,7 @@ val from_channel :
       See [from_string] for the meaning of the optional arguments. *)
 
 val from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -363,7 +351,7 @@ val from_file :
 
 
 type lexer_state = Lexer_state.t = {
-  buf : Bi_outbuf.t;
+  buf : Buffer.t;
   mutable lnum : int;
   mutable bol : int;
   mutable fname : string option;
@@ -373,7 +361,7 @@ type lexer_state = Lexer_state.t = {
     *)
 
 val init_lexer :
-  ?buf: Bi_outbuf.t ->
+  ?buf: Buffer.t ->
   ?fname: string ->
   ?lnum: int ->
   unit -> lexer_state
@@ -393,7 +381,7 @@ val from_lexbuf :
       the end of the JSON value and the end of the input. *)
 
 val stream_from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -402,7 +390,7 @@ val stream_from_string :
       See [from_string] for the meaning of the optional arguments. *)
 
 val stream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -418,7 +406,7 @@ val stream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val stream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -445,7 +433,7 @@ type json_line = [ `Json of t | `Exn of exn ]
     (** The type of values resulting from a parsing attempt of a JSON value. *)
 
 val linestream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -459,7 +447,7 @@ val linestream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val linestream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> json_line Stream.t
@@ -599,29 +587,29 @@ sig
    This module provides combinators for extracting fields from JSON
    values. This approach is recommended for reading a few fields
    from data returned by public APIs. However for more complex applications
-   we recommend {{:https://github.com/MyLifeLabs/atdgen}Atdgen}.
+   we recommend {{:https://github.com/ahrefs/atd}Atdgen}.
 
    Here is some sample JSON data:
 {v
-\{
+{
   "id": "398eb027",
   "name": "John Doe",
   "pages": [
-    \{
+    {
       "id": 1,
       "title": "The Art of Flipping Coins",
       "url": "http://example.com/398eb027/1"
     },
-    \{
+    {
       "id": 2,
       "deleted": true
     },
-    \{
+    {
       "id": 3,
       "title": "Artichoke Salad",
       "url": "http://example.com/398eb027/3"
     },
-    \{
+    {
       "id": 4,
       "title": "Flying Bananas",
       "url": "http://example.com/398eb027/4"
@@ -665,10 +653,6 @@ exception Undefined of string * t
       return undefined. Currently this only happens when an array index is out
       of bounds. *)
 
-val ( |> ) : 'a -> ('a -> 'b) -> 'b
-(** @deprecated Forward pipe operator; useful for composing JSON
-    access functions without too many parentheses *)
-
 val keys : t -> string list
   (** Returns all the key names in the given JSON object *)
 
@@ -870,11 +854,6 @@ All possible cases defined in Yojson:
 	    Syntax: [<"Foo">] or [<"Bar":123>].
 *)
 
-type json = t [@@deprecated "json types are being renamed and will be removed in the next Yojson major version. Use type t instead"]
-(**
- * Compatibility type alias for type `t`
- *)
-
 (*
   Note to adventurers: ocamldoc does not support inline comments
   on each polymorphic variant, and cppo doesn't allow to concatenate
@@ -915,13 +894,13 @@ v}
 (** {2 JSON writers} *)
 
 val to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t -> string
   (** Write a compact JSON value to a string.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create]. The buffer is cleared of all contents
+      [Buffer.create]. The buffer is cleared of all contents
       before starting and right before returning.
       @param len initial length of the output buffer.
       @param std use only standard JSON syntax,
@@ -932,13 +911,13 @@ val to_string :
   *)
 
 val to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t -> unit
   (** Write a compact JSON value to a channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_channel_writer] on the same channel.
+      [Buffer.create] on the same channel.
       [buf] is flushed right
       before [to_channel] returns but the [out_channel] is
       not flushed automatically.
@@ -946,13 +925,13 @@ val to_channel :
       See [to_string] for the role of the other optional arguments. *)
 
 val to_output :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   < output : string -> int -> int -> int; .. > -> t -> unit
   (** Write a compact JSON value to an OO channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_output_writer] on the same channel.
+      [Buffer.add_channel] on the same channel.
       [buf] is flushed right
       before [to_output] returns but the channel itself is
       not flushed automatically.
@@ -966,14 +945,14 @@ val to_file :
   (** Write a compact JSON value to a file.
       See [to_string] for the role of the optional arguments. *)
 
-val to_outbuf :
+val to_buffer :
   ?std:bool ->
-  Bi_outbuf.t -> t -> unit
+  Buffer.t -> t -> unit
   (** Write a compact JSON value to an existing buffer.
       See [to_string] for the role of the optional argument. *)
 
 val stream_to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t Stream.t -> string
@@ -982,7 +961,7 @@ val stream_to_string :
       See [to_string] for the role of the optional arguments. *)
 
 val stream_to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t Stream.t -> unit
@@ -998,15 +977,15 @@ val stream_to_file :
       a file.
       See [to_string] for the role of the optional arguments. *)
 
-val stream_to_outbuf :
+val stream_to_buffer :
   ?std:bool ->
-  Bi_outbuf.t ->
+  Buffer.t ->
   t Stream.t -> unit
   (** Write a newline-separated sequence of compact one-line JSON values to
       an existing buffer.
       See [to_string] for the role of the optional arguments. *)
 
-val write_t : Bi_outbuf.t -> t -> unit
+val write_t : Buffer.t -> t -> unit
 (** Write the given JSON value to the given buffer.
     Provided as a writer function for atdgen.
 *)
@@ -1021,49 +1000,42 @@ val sort : t -> t
 (**/**)
 (* begin undocumented section *)
 
-val write_null : Bi_outbuf.t -> unit -> unit
-val write_bool : Bi_outbuf.t -> bool -> unit
+val write_null : Buffer.t -> unit -> unit
+val write_bool : Buffer.t -> bool -> unit
 # 113 "write.mli"
-val write_int : Bi_outbuf.t -> int -> unit
+val write_int : Buffer.t -> int -> unit
 # 116 "write.mli"
-val write_float : Bi_outbuf.t -> float -> unit
-val write_std_float : Bi_outbuf.t -> float -> unit
-val write_float_fast : Bi_outbuf.t -> float -> unit
-val write_std_float_fast : Bi_outbuf.t -> float -> unit
-val write_float_prec : int -> Bi_outbuf.t -> float -> unit
-val write_std_float_prec : int -> Bi_outbuf.t -> float -> unit
+val write_float : Buffer.t -> float -> unit
+val write_std_float : Buffer.t -> float -> unit
+val write_float_fast : Buffer.t -> float -> unit
+val write_std_float_fast : Buffer.t -> float -> unit
+val write_float_prec : int -> Buffer.t -> float -> unit
+val write_std_float_prec : int -> Buffer.t -> float -> unit
 # 124 "write.mli"
-val write_string : Bi_outbuf.t -> string -> unit
+val write_string : Buffer.t -> string -> unit
 
 # 128 "write.mli"
-val write_intlit : Bi_outbuf.t -> string -> unit
+val write_intlit : Buffer.t -> string -> unit
 
 # 137 "write.mli"
-val write_assoc : Bi_outbuf.t -> (string * t) list -> unit
-val write_list : Bi_outbuf.t -> t list -> unit
+val write_assoc : Buffer.t -> (string * t) list -> unit
+val write_list : Buffer.t -> t list -> unit
 # 140 "write.mli"
-val write_tuple : Bi_outbuf.t -> t list -> unit
-val write_std_tuple : Bi_outbuf.t -> t list -> unit
+val write_tuple : Buffer.t -> t list -> unit
+val write_std_tuple : Buffer.t -> t list -> unit
 # 144 "write.mli"
-val write_variant : Bi_outbuf.t -> string -> t option -> unit
-val write_std_variant : Bi_outbuf.t -> string -> t option -> unit
+val write_variant : Buffer.t -> string -> t option -> unit
+val write_std_variant : Buffer.t -> string -> t option -> unit
 
 # 148 "write.mli"
-val write_json : Bi_outbuf.t -> t -> unit
-val write_std_json : Bi_outbuf.t -> t -> unit
+val write_json : Buffer.t -> t -> unit
+val write_std_json : Buffer.t -> t -> unit
 
 (* end undocumented section *)
 (**/**)
 # 1 "write2.mli"
 (** {2 JSON pretty-printing} *)
 
-val pretty_format : ?std:bool -> t -> Easy_format.t
-  (** Convert into a pretty-printable tree.
-      See [to_string] for the role of the optional [std] argument.
-
-      @see <http://martin.jambon.free.fr/easy-format.html> Easy-format
-  *)
-
 val pretty_print : ?std:bool -> Format.formatter -> t -> unit
   (** Pretty-print into a {!Format.formatter}.
       See [to_string] for the role of the optional [std] argument.
@@ -1094,7 +1066,7 @@ exception Finally of exn * exn
 (** Exception describing a failure in both finalizer and parsing. *)
 
 val from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -1107,7 +1079,7 @@ val from_string :
   *)
 
 val from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   in_channel -> t
@@ -1115,7 +1087,7 @@ val from_channel :
       See [from_string] for the meaning of the optional arguments. *)
 
 val from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -1124,7 +1096,7 @@ val from_file :
 
 
 type lexer_state = Lexer_state.t = {
-  buf : Bi_outbuf.t;
+  buf : Buffer.t;
   mutable lnum : int;
   mutable bol : int;
   mutable fname : string option;
@@ -1134,7 +1106,7 @@ type lexer_state = Lexer_state.t = {
     *)
 
 val init_lexer :
-  ?buf: Bi_outbuf.t ->
+  ?buf: Buffer.t ->
   ?fname: string ->
   ?lnum: int ->
   unit -> lexer_state
@@ -1154,7 +1126,7 @@ val from_lexbuf :
       the end of the JSON value and the end of the input. *)
 
 val stream_from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -1163,7 +1135,7 @@ val stream_from_string :
       See [from_string] for the meaning of the optional arguments. *)
 
 val stream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -1179,7 +1151,7 @@ val stream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val stream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -1206,7 +1178,7 @@ type json_line = [ `Json of t | `Exn of exn ]
     (** The type of values resulting from a parsing attempt of a JSON value. *)
 
 val linestream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -1220,7 +1192,7 @@ val linestream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val linestream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> json_line Stream.t
@@ -1360,29 +1332,29 @@ sig
    This module provides combinators for extracting fields from JSON
    values. This approach is recommended for reading a few fields
    from data returned by public APIs. However for more complex applications
-   we recommend {{:https://github.com/MyLifeLabs/atdgen}Atdgen}.
+   we recommend {{:https://github.com/ahrefs/atd}Atdgen}.
 
    Here is some sample JSON data:
 {v
-\{
+{
   "id": "398eb027",
   "name": "John Doe",
   "pages": [
-    \{
+    {
       "id": 1,
       "title": "The Art of Flipping Coins",
       "url": "http://example.com/398eb027/1"
     },
-    \{
+    {
       "id": 2,
       "deleted": true
     },
-    \{
+    {
       "id": 3,
       "title": "Artichoke Salad",
       "url": "http://example.com/398eb027/3"
     },
-    \{
+    {
       "id": 4,
       "title": "Flying Bananas",
       "url": "http://example.com/398eb027/4"
@@ -1426,10 +1398,6 @@ exception Undefined of string * t
       return undefined. Currently this only happens when an array index is out
       of bounds. *)
 
-val ( |> ) : 'a -> ('a -> 'b) -> 'b
-(** @deprecated Forward pipe operator; useful for composing JSON
-    access functions without too many parentheses *)
-
 val keys : t -> string list
   (** Returns all the key names in the given JSON object *)
 
@@ -1625,11 +1593,6 @@ All possible cases defined in Yojson:
 	    Syntax: [<"Foo">] or [<"Bar":123>].
 *)
 
-type json = t [@@deprecated "json types are being renamed and will be removed in the next Yojson major version. Use type t instead"]
-(**
- * Compatibility type alias for type `t`
- *)
-
 (*
   Note to adventurers: ocamldoc does not support inline comments
   on each polymorphic variant, and cppo doesn't allow to concatenate
@@ -1654,13 +1617,13 @@ val equal : t -> t -> bool
 (** {2 JSON writers} *)
 
 val to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t -> string
   (** Write a compact JSON value to a string.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create]. The buffer is cleared of all contents
+      [Buffer.create]. The buffer is cleared of all contents
       before starting and right before returning.
       @param len initial length of the output buffer.
       @param std use only standard JSON syntax,
@@ -1671,13 +1634,13 @@ val to_string :
   *)
 
 val to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t -> unit
   (** Write a compact JSON value to a channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_channel_writer] on the same channel.
+      [Buffer.create] on the same channel.
       [buf] is flushed right
       before [to_channel] returns but the [out_channel] is
       not flushed automatically.
@@ -1685,13 +1648,13 @@ val to_channel :
       See [to_string] for the role of the other optional arguments. *)
 
 val to_output :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   < output : string -> int -> int -> int; .. > -> t -> unit
   (** Write a compact JSON value to an OO channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_output_writer] on the same channel.
+      [Buffer.add_channel] on the same channel.
       [buf] is flushed right
       before [to_output] returns but the channel itself is
       not flushed automatically.
@@ -1705,14 +1668,14 @@ val to_file :
   (** Write a compact JSON value to a file.
       See [to_string] for the role of the optional arguments. *)
 
-val to_outbuf :
+val to_buffer :
   ?std:bool ->
-  Bi_outbuf.t -> t -> unit
+  Buffer.t -> t -> unit
   (** Write a compact JSON value to an existing buffer.
       See [to_string] for the role of the optional argument. *)
 
 val stream_to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t Stream.t -> string
@@ -1721,7 +1684,7 @@ val stream_to_string :
       See [to_string] for the role of the optional arguments. *)
 
 val stream_to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t Stream.t -> unit
@@ -1737,15 +1700,15 @@ val stream_to_file :
       a file.
       See [to_string] for the role of the optional arguments. *)
 
-val stream_to_outbuf :
+val stream_to_buffer :
   ?std:bool ->
-  Bi_outbuf.t ->
+  Buffer.t ->
   t Stream.t -> unit
   (** Write a newline-separated sequence of compact one-line JSON values to
       an existing buffer.
       See [to_string] for the role of the optional arguments. *)
 
-val write_t : Bi_outbuf.t -> t -> unit
+val write_t : Buffer.t -> t -> unit
 (** Write the given JSON value to the given buffer.
     Provided as a writer function for atdgen.
 *)
@@ -1760,42 +1723,35 @@ val sort : t -> t
 (**/**)
 (* begin undocumented section *)
 
-val write_null : Bi_outbuf.t -> unit -> unit
-val write_bool : Bi_outbuf.t -> bool -> unit
+val write_null : Buffer.t -> unit -> unit
+val write_bool : Buffer.t -> bool -> unit
 
 # 128 "write.mli"
-val write_intlit : Bi_outbuf.t -> string -> unit
+val write_intlit : Buffer.t -> string -> unit
 # 131 "write.mli"
-val write_floatlit : Bi_outbuf.t -> string -> unit
+val write_floatlit : Buffer.t -> string -> unit
 # 134 "write.mli"
-val write_stringlit : Bi_outbuf.t -> string -> unit
+val write_stringlit : Buffer.t -> string -> unit
 
 # 137 "write.mli"
-val write_assoc : Bi_outbuf.t -> (string * t) list -> unit
-val write_list : Bi_outbuf.t -> t list -> unit
+val write_assoc : Buffer.t -> (string * t) list -> unit
+val write_list : Buffer.t -> t list -> unit
 # 140 "write.mli"
-val write_tuple : Bi_outbuf.t -> t list -> unit
-val write_std_tuple : Bi_outbuf.t -> t list -> unit
+val write_tuple : Buffer.t -> t list -> unit
+val write_std_tuple : Buffer.t -> t list -> unit
 # 144 "write.mli"
-val write_variant : Bi_outbuf.t -> string -> t option -> unit
-val write_std_variant : Bi_outbuf.t -> string -> t option -> unit
+val write_variant : Buffer.t -> string -> t option -> unit
+val write_std_variant : Buffer.t -> string -> t option -> unit
 
 # 148 "write.mli"
-val write_json : Bi_outbuf.t -> t -> unit
-val write_std_json : Bi_outbuf.t -> t -> unit
+val write_json : Buffer.t -> t -> unit
+val write_std_json : Buffer.t -> t -> unit
 
 (* end undocumented section *)
 (**/**)
 # 1 "write2.mli"
 (** {2 JSON pretty-printing} *)
 
-val pretty_format : ?std:bool -> t -> Easy_format.t
-  (** Convert into a pretty-printable tree.
-      See [to_string] for the role of the optional [std] argument.
-
-      @see <http://martin.jambon.free.fr/easy-format.html> Easy-format
-  *)
-
 val pretty_print : ?std:bool -> Format.formatter -> t -> unit
   (** Pretty-print into a {!Format.formatter}.
       See [to_string] for the role of the optional [std] argument.
@@ -1826,7 +1782,7 @@ exception Finally of exn * exn
 (** Exception describing a failure in both finalizer and parsing. *)
 
 val from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -1839,7 +1795,7 @@ val from_string :
   *)
 
 val from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   in_channel -> t
@@ -1847,7 +1803,7 @@ val from_channel :
       See [from_string] for the meaning of the optional arguments. *)
 
 val from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t
@@ -1856,7 +1812,7 @@ val from_file :
 
 
 type lexer_state = Lexer_state.t = {
-  buf : Bi_outbuf.t;
+  buf : Buffer.t;
   mutable lnum : int;
   mutable bol : int;
   mutable fname : string option;
@@ -1866,7 +1822,7 @@ type lexer_state = Lexer_state.t = {
     *)
 
 val init_lexer :
-  ?buf: Bi_outbuf.t ->
+  ?buf: Buffer.t ->
   ?fname: string ->
   ?lnum: int ->
   unit -> lexer_state
@@ -1886,7 +1842,7 @@ val from_lexbuf :
       the end of the JSON value and the end of the input. *)
 
 val stream_from_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -1895,7 +1851,7 @@ val stream_from_string :
       See [from_string] for the meaning of the optional arguments. *)
 
 val stream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -1911,7 +1867,7 @@ val stream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val stream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> t Stream.t
@@ -1938,7 +1894,7 @@ type json_line = [ `Json of t | `Exn of exn ]
     (** The type of values resulting from a parsing attempt of a JSON value. *)
 
 val linestream_from_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fin:(unit -> unit) ->
   ?fname:string ->
   ?lnum:int ->
@@ -1952,7 +1908,7 @@ val linestream_from_channel :
       See [from_string] for the meaning of the other optional arguments. *)
 
 val linestream_from_file :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?fname:string ->
   ?lnum:int ->
   string -> json_line Stream.t
@@ -2149,11 +2105,6 @@ All possible cases defined in Yojson:
 	    Syntax: [<"Foo">] or [<"Bar":123>].
 *)
 
-type json = t [@@deprecated "json types are being renamed and will be removed in the next Yojson major version. Use type t instead"]
-(**
- * Compatibility type alias for type `t`
- *)
-
 (*
   Note to adventurers: ocamldoc does not support inline comments
   on each polymorphic variant, and cppo doesn't allow to concatenate
@@ -2180,13 +2131,13 @@ type json_max = t
 (** {2 JSON writers} *)
 
 val to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t -> string
   (** Write a compact JSON value to a string.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create]. The buffer is cleared of all contents
+      [Buffer.create]. The buffer is cleared of all contents
       before starting and right before returning.
       @param len initial length of the output buffer.
       @param std use only standard JSON syntax,
@@ -2197,13 +2148,13 @@ val to_string :
   *)
 
 val to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t -> unit
   (** Write a compact JSON value to a channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_channel_writer] on the same channel.
+      [Buffer.create] on the same channel.
       [buf] is flushed right
       before [to_channel] returns but the [out_channel] is
       not flushed automatically.
@@ -2211,13 +2162,13 @@ val to_channel :
       See [to_string] for the role of the other optional arguments. *)
 
 val to_output :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   < output : string -> int -> int -> int; .. > -> t -> unit
   (** Write a compact JSON value to an OO channel.
       @param buf allows to reuse an existing buffer created with
-      [Bi_outbuf.create_output_writer] on the same channel.
+      [Buffer.add_channel] on the same channel.
       [buf] is flushed right
       before [to_output] returns but the channel itself is
       not flushed automatically.
@@ -2231,14 +2182,14 @@ val to_file :
   (** Write a compact JSON value to a file.
       See [to_string] for the role of the optional arguments. *)
 
-val to_outbuf :
+val to_buffer :
   ?std:bool ->
-  Bi_outbuf.t -> t -> unit
+  Buffer.t -> t -> unit
   (** Write a compact JSON value to an existing buffer.
       See [to_string] for the role of the optional argument. *)
 
 val stream_to_string :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   t Stream.t -> string
@@ -2247,7 +2198,7 @@ val stream_to_string :
       See [to_string] for the role of the optional arguments. *)
 
 val stream_to_channel :
-  ?buf:Bi_outbuf.t ->
+  ?buf:Buffer.t ->
   ?len:int ->
   ?std:bool ->
   out_channel -> t Stream.t -> unit
@@ -2263,15 +2214,15 @@ val stream_to_file :
       a file.
       See [to_string] for the role of the optional arguments. *)
 
-val stream_to_outbuf :
+val stream_to_buffer :
   ?std:bool ->
-  Bi_outbuf.t ->
+  Buffer.t ->
   t Stream.t -> unit
   (** Write a newline-separated sequence of compact one-line JSON values to
       an existing buffer.
       See [to_string] for the role of the optional arguments. *)
 
-val write_t : Bi_outbuf.t -> t -> unit
+val write_t : Buffer.t -> t -> unit
 (** Write the given JSON value to the given buffer.
     Provided as a writer function for atdgen.
 *)
@@ -2286,53 +2237,46 @@ val sort : t -> t
 (**/**)
 (* begin undocumented section *)
 
-val write_null : Bi_outbuf.t -> unit -> unit
-val write_bool : Bi_outbuf.t -> bool -> unit
+val write_null : Buffer.t -> unit -> unit
+val write_bool : Buffer.t -> bool -> unit
 # 113 "write.mli"
-val write_int : Bi_outbuf.t -> int -> unit
+val write_int : Buffer.t -> int -> unit
 # 116 "write.mli"
-val write_float : Bi_outbuf.t -> float -> unit
-val write_std_float : Bi_outbuf.t -> float -> unit
-val write_float_fast : Bi_outbuf.t -> float -> unit
-val write_std_float_fast : Bi_outbuf.t -> float -> unit
-val write_float_prec : int -> Bi_outbuf.t -> float -> unit
-val write_std_float_prec : int -> Bi_outbuf.t -> float -> unit
+val write_float : Buffer.t -> float -> unit
+val write_std_float : Buffer.t -> float -> unit
+val write_float_fast : Buffer.t -> float -> unit
+val write_std_float_fast : Buffer.t -> float -> unit
+val write_float_prec : int -> Buffer.t -> float -> unit
+val write_std_float_prec : int -> Buffer.t -> float -> unit
 # 124 "write.mli"
-val write_string : Bi_outbuf.t -> string -> unit
+val write_string : Buffer.t -> string -> unit
 
 # 128 "write.mli"
-val write_intlit : Bi_outbuf.t -> string -> unit
+val write_intlit : Buffer.t -> string -> unit
 # 131 "write.mli"
-val write_floatlit : Bi_outbuf.t -> string -> unit
+val write_floatlit : Buffer.t -> string -> unit
 # 134 "write.mli"
-val write_stringlit : Bi_outbuf.t -> string -> unit
+val write_stringlit : Buffer.t -> string -> unit
 
 # 137 "write.mli"
-val write_assoc : Bi_outbuf.t -> (string * t) list -> unit
-val write_list : Bi_outbuf.t -> t list -> unit
+val write_assoc : Buffer.t -> (string * t) list -> unit
+val write_list : Buffer.t -> t list -> unit
 # 140 "write.mli"
-val write_tuple : Bi_outbuf.t -> t list -> unit
-val write_std_tuple : Bi_outbuf.t -> t list -> unit
+val write_tuple : Buffer.t -> t list -> unit
+val write_std_tuple : Buffer.t -> t list -> unit
 # 144 "write.mli"
-val write_variant : Bi_outbuf.t -> string -> t option -> unit
-val write_std_variant : Bi_outbuf.t -> string -> t option -> unit
+val write_variant : Buffer.t -> string -> t option -> unit
+val write_std_variant : Buffer.t -> string -> t option -> unit
 
 # 148 "write.mli"
-val write_json : Bi_outbuf.t -> t -> unit
-val write_std_json : Bi_outbuf.t -> t -> unit
+val write_json : Buffer.t -> t -> unit
+val write_std_json : Buffer.t -> t -> unit
 
 (* end undocumented section *)
 (**/**)
 # 1 "write2.mli"
 (** {2 JSON pretty-printing} *)
 
-val pretty_format : ?std:bool -> t -> Easy_format.t
-  (** Convert into a pretty-printable tree.
-      See [to_string] for the role of the optional [std] argument.
-
-      @see <http://martin.jambon.free.fr/easy-format.html> Easy-format
-  *)
-
 val pretty_print : ?std:bool -> Format.formatter -> t -> unit
   (** Pretty-print into a {!Format.formatter}.
       See [to_string] for the role of the optional [std] argument.
